==> ilitools-1.1.6-2.1-any.pkg.tar.zst: usr/lib/python3.12/site-packages/ilitools/target/container_tar.py <==
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# Copyright (c) 2019-2023, AllWorldIT
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Container tar docker target."""

import logging
import os
from typing import Dict, Optional
from .container_dir import IliTargetContainerDir
from ..exceptions import IliException
from ..filesystem import IliFilesystem
from .. import util

FILE_FORMATS: Dict[str, str] = {
    ".tar": "cat",
    ".tar.gz": "gzip",
    ".tar.bz2": "bzip2",
    ".tar.xz": "xz",
    ".tar.zst": "zstd",
}


# pylint: disable=too-many-instance-attributes
class IliTargetContainerTar(IliTargetContainerDir):
    """
    Ili container tar target.

    This class inherits from `IliTargetContainerDir`.
    """

    _build_dir: Optional[str]
    _compressor: Optional[str]

    def target_init(self) -> None:
        """Initialize object. This is called during __init__()."""

        # Hand over to parent
        super().target_init()

        # Setup internals
        self._build_dir = None
        self._compressor = None

    def configure_target(self) -> None:
        """Configure target."""

        # Grab target filename for the container
        target_file: Optional[str] = self.get_config_from_args_profile({"name": "target_file"})
        if not target_file:
            raise IliException("No target file specified, use --target-file or the configuration file")
        self.target = target_file

        build_dir = None
        for ext, compressor in FILE_FORMATS.items():
            # Check for format match
            # NK: Make mypy and pylance happy by adding self.target
            if self.target and self.target.endswith(ext):
                # Set the build directory
                build_dir = f"{self.target}.BUILD-TMP"
                self.compressor = compressor
        # If we didn't get a build_dir it means we didn't understand the file extension
        if not build_dir:
            raise IliException(f"Invalid extension for target file '{self.target}'")

        # Save build dir
        self.build_dir = build_dir

    def validate_configuration_target(self) -> None:
        """Validate configuration."""

        if self.build_dir is None:
            raise IliException("build_dir must be set")

        # Make sure build directory does not exist
        if os.path.exists(self.build_dir):
            raise IliException(f'Temporary build directory "{self.build_dir}" already exists')

    def prepare_target(self) -> None:
        """
        Prepare target.

        This must be overridden for each target.
        """

        if self.build_dir is None:
            raise IliException("build_dir must be set")

        logging.debug("  - Preparing build directory: %s", self.build_dir)

        # Make the build directory and the rootfs directory
        try:
            os.mkdir(self.build_dir, mode=0o0750)
            self.add_temp_path(self.build_dir)
        except OSError as err:
            raise IliException(f"Failed to create build directory '{self.build_dir}': {err}") from None

        # Work out our rootfs path
        rootfs_path = f"{self.build_dir}/rootfs"

        # Add rootfs filesystem
        self.rootfs = IliFilesystem(
            source=rootfs_path,
            fstype="bind",
            mount_root=rootfs_path,
            mount_path="/",
        )

    def finalize_target(self) -> None:
        """
        Finalize target.

        Here we create the final tar archive. This is after
        """

        if self.rootfs is None:
            raise IliException("rootfs must be set")
        if self.rootfs.mount_point is None:
            raise IliException("rootfs mount_point must be set")
        if self.target is None:
            raise IliException("target must be set")
        if self.compressor is None:
            raise IliException("compressor must be set")

        logging.debug("  - Creating final target '%s'", self.target)

        util.run_host(
            [
                "/usr/bin/fakeroot",
                "--",
                "/usr/bin/tar",
                "--numeric-owner",
                "--xattrs",
                "--acls",
                "--directory",
                self.rootfs.mount_point,
                "--file",
                self.target,
                "--create",
                ".",
                "--use-compress-program",
                self.compressor,
            ]
        )

    @property
    def build_dir(self) -> Optional[str]:
        """Return the build dir we're going to use."""
        return self._build_dir

    @build_dir.setter
    def build_dir(self, build_dir: str) -> None:
        """Set the build dir to use."""
        self._build_dir = build_dir

    @property
    def compressor(self) -> Optional[str]:
        """Return compressor we're going to use."""
        return self._compressor

    @compressor.setter
    def compressor(self, compressor: str) -> None:
        """Set the compressor to use."""
        self._compressor = compressor

==> ilitools-1.2.4-1.1-any.pkg.tar.zst: usr/lib/python3.12/site-packages/ilitools/target/container_tar.py <==
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# Copyright (c) 2019-2024, AllWorldIT
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Container tar docker target."""

import logging
import os
from typing import Dict, Optional

from .. import util
from ..exceptions import IliException
from ..filesystem import IliFilesystem
from .container_dir import IliTargetContainerDir

__all__ = ["IliTargetContainerTar"]

FILE_FORMATS: Dict[str, str] = {
    ".tar": "cat",
    ".tar.gz": "gzip",
    ".tar.bz2": "bzip2",
    ".tar.xz": "xz",
    ".tar.zst": "zstd",
}


class IliTargetContainerTar(IliTargetContainerDir):  # pylint: disable=too-many-instance-attributes
    """
    Ili container tar target.

    This class inherits from `IliTargetContainerDir`.
    """

    _build_dir: Optional[str]
    _compressor: Optional[str]

    def target_init(self) -> None:
        """Initialize object. This is called during __init__()."""

        # Hand over to parent
        super().target_init()

        # Setup internals
        self._build_dir = None
        self._compressor = None

    def configure_target(self) -> None:
        """Configure target."""

        # Grab target filename for the container
        target_file: Optional[str] = self.get_config_from_args_profile({"name": "target_file"})
        if not target_file:
            raise IliException("No target file specified, use --target-file or the configuration file")
        self.target = target_file

        build_dir = None
        for ext, compressor in FILE_FORMATS.items():
            # Check for format match
            # NK: Make mypy and pylance happy by adding self.target
            if self.target and self.target.endswith(ext):
                # Set the build directory
                build_dir = f"{self.target}.BUILD-TMP"
                self.compressor = compressor
        # If we didn't get a build_dir it means we didn't understand the file extension
        if not build_dir:
            raise IliException(f"Invalid extension for target file '{self.target}'")

        # Save build dir
        self.build_dir = build_dir

    def validate_configuration_target(self) -> None:
        """Validate configuration."""

        if self.build_dir is None:
            raise IliException("build_dir must be set")

        # Make sure build directory does not exist
        if os.path.exists(self.build_dir):
            raise IliException(f'Temporary build directory "{self.build_dir}" already exists')

    def prepare_target(self) -> None:
        """
        Prepare target.

        This must be overridden for each target.
        """

        if self.build_dir is None:
            raise IliException("build_dir must be set")

        logging.debug("  - Preparing build directory: %s", self.build_dir)

        # Make the build directory and the rootfs directory
        try:
            os.mkdir(self.build_dir, mode=0o0750)
            self.add_temp_path(self.build_dir)
        except OSError as err:
            raise IliException(f"Failed to create build directory '{self.build_dir}': {err}") from None

        # Work out our rootfs path
        rootfs_path = f"{self.build_dir}/rootfs"

        # Add rootfs filesystem
        self.rootfs = IliFilesystem(
            source=rootfs_path,
            fstype="bind",
            mount_root=rootfs_path,
            mount_path="/",
        )

    def finalize_target(self) -> None:
        """
        Finalize target.

        Here we create the final tar archive. This is after
        """

        if self.rootfs is None:
            raise IliException("rootfs must be set")
        if self.rootfs.mount_point is None:
            raise IliException("rootfs mount_point must be set")
        if self.target is None:
            raise IliException("target must be set")
        if self.compressor is None:
            raise IliException("compressor must be set")

        logging.debug("  - Creating final target '%s'", self.target)

        util.run_host(
            [
                "/usr/bin/fakeroot",
                "--",
                "/usr/bin/tar",
                "--numeric-owner",
                "--xattrs",
                "--acls",
                "--directory",
                self.rootfs.mount_point,
                "--file",
                self.target,
                "--create",
                ".",
                "--use-compress-program",
                self.compressor,
            ]
        )

    @property
    def build_dir(self) -> Optional[str]:
        """Return the build dir we're going to use."""
        return self._build_dir

    @build_dir.setter
    def build_dir(self, build_dir: str) -> None:
        """Set the build dir to use."""
        self._build_dir = build_dir

    @property
    def compressor(self) -> Optional[str]:
        """Return compressor we're going to use."""
        return self._compressor

    @compressor.setter
    def compressor(self, compressor: str) -> None:
        """Set the compressor to use."""
        self._compressor = compressor
